@@ -1,6 +1,6 @@
 /* 
  * -- High Performance Computing Linpack Benchmark (HPL)                
- *    HPL - 2.1 - October 26, 2012                          
+ *    HPL - 2.2 - February 24, 2016                          
  *    Antoine P. Petitet                                                
  *    University of Tennessee, Knoxville                                
  *    Innovative Computing Laboratory                                 
@@ -99,6 +99,9 @@ void HPL_pdgesvK1
    int                        N, depth, icurcol=0, j, jb, jj=0, jstart,
                               k, mycol, n, nb, nn, npcol, nq,
                               tag=MSGID_BEGIN_FACT, test=HPL_KEEP_TESTING;
+#ifdef HPL_PROGRESS_REPORT
+   double start_time, time, gflops;
+#endif
 /* ..
  * .. Executable Statements ..
  */
@@ -107,6 +110,11 @@ void HPL_pdgesvK1
    N     = A->n;        nb           = A->nb; 
 
    if( N <= 0 ) return;
+
+#ifdef HPL_PROGRESS_REPORT
+   start_time = HPL_timer_walltime();
+#endif
+
 /*
  * Allocate a panel list of length depth + 1 (depth >= 1)
  */
@@ -158,6 +166,15 @@ void HPL_pdgesvK1
    for( j = jstart; j < N; j += nb )
    {
       n = N - j; jb = Mmin( n, nb );
+#ifdef HPL_PROGRESS_REPORT
+      /* if this is process 0,0 and not the first panel */
+      if ( GRID->myrow == 0 && mycol == 0 && j > 0 ) 
+      {
+          time = HPL_timer_walltime() - start_time;
+          gflops = 2.0*(N*(double)N*N - n*(double)n*n)/3.0/(time > 0.0 ? time : 1e-6)/1e9;
+          HPL_fprintf( stdout, "Column=%09d Fraction=%4.1f%% Gflops=%9.3e\n", j, j*100.0/N, gflops);
+      }
+#endif
 /*
  * Allocate current panel resources - Finish latest update - Factor and
  * broadcast current panel
